"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
module.exports.createMarkdownIt = void 0;
const fs_1 = __importDefault(require("fs"));
const markdown_it_1 = __importDefault(require("markdown-it"));
const shiki = __importStar(require("shiki"));
const utils_1 = require("./utils");
const plugin = (options = {}) => {
    options = {
        codeTheme: 'material-lighter',
        className: 'markdown-body',
        ...options,
        injectStyle: 'injectStyle' in options && !options.injectStyle
            ? ''
            : typeof options.injectStyle === 'string'
                ? options.injectStyle
                : 'github-markdown-css/github-marker-light.css',
    };
    const markdownItPromise = createMarkdownIt(options);
    const pattern = /\.md(\?(html|react|vue))?$/;
    return {
        name: 'mdm',
        async resolveId(id, importer, options) {
            if (pattern.test(id)) {
                const base = id.replace(pattern, '.md');
                const suffix = id.replace(base, '');
                const resolved = await this.resolve(base, importer, {
                    ...options,
                    skipSelf: true,
                });
                resolved.id += suffix;
                return resolved;
            }
        },
        load(id) {
            if (pattern.test(id)) {
                const base = id.replace(pattern, '.md');
                return fs_1.default.readFileSync(base).toString();
            }
        },
        async transform(code, id) {
            if (pattern.test(id)) {
                const raw = await markdownItPromise.then((markdownIt) => markdownIt.render(code).trim());
                const html = `\`${raw}\``;
                const injectStyleModule = options.injectStyle
                    ? `import '${options.injectStyle}'`
                    : '';
                let defaultModule = '';
                if (/\.md(\?html)?$/.test(id)) {
                    defaultModule = (0, utils_1.createHtmlModule)(html, options.className);
                }
                else if (/\.md(\?react)$/.test(id)) {
                    defaultModule = (0, utils_1.createReactComponent)(html, options.className);
                }
                else if (/\.md(\?vue)$/.test(id)) {
                    defaultModule = (0, utils_1.createVueComponent)(html, options.className);
                }
                if (defaultModule) {
                    return {
                        code: injectStyleModule + '\n\n' + defaultModule,
                    };
                }
            }
        },
    };
};
module.exports = plugin;
module.exports["default"] = plugin;
function createMarkdownIt(options) {
    return shiki
        .getHighlighter({
        theme: options.codeTheme,
    })
        .then((highlighter) => {
        return new markdown_it_1.default({
            linkify: true,
            typographer: true,
            ...options,
            html: true,
            highlight: (code, lang) => {
                return highlighter.codeToHtml(code, { lang });
            },
        });
    });
}
module.exports.createMarkdownIt = createMarkdownIt;
